@@ -4,11 +4,11 @@
 
 __version__ = "0.1.0"
 __author__ = 'Ido Carmi'
-__credits__ = 'Hermetric Software Services Ltd.'
+__credits__ = 'hermetric.com'
 
 
 # import pandas_sets
-from . import xagg, xcache, xchecks, xmunge, xnp, xpd, xplt
+from . import xagg, xcache, xchecks, xmunge, xnp, xpd, xplt, utilities
 
 
 def monkey_patch():
