@@ -34,3 +34,9 @@ def check_no_dups(sa):
     """
     assert len(sa) == len(np.unique(sa))
 
+
+def get_unique(df, cols):
+    df = df[cols]
+    df = df.drop_duplicates(cols)
+    df = df.sort_values(cols)
+    return df
